%% Load Data
close all
clear all

load('edgebulkdata.mat')
load('DataForPaper_LineSPec_pointSpec.mat')

% Define voltage and current setpoints
voltage_setpoint = -500;  % Example voltage setpoint in millivolts
current_setpoint = 0.5;  % Example current setpoint in nanoamperes

%% Process and Plot dI/dV Map

II = conv2(interp2(LIA_DOS_LineSPec(61:241,1:end),1),1);
II = smooth2a(II, 2, 2);

x1 = 61;
x2 = 241;
dim = size(II);

% Create and save the dI/dV map
figure()
imagesc([0 dim(2)], [Xdata(x1) Xdata(x2)], log(II))
colorbar
colormap jet
% caxis([-1.03 -0.2])
set(gcf,'units','points','position',[25,35,1100,540])
set(gca,'FontSize',20)
xlabel('Distance (pixels)')
ylabel('Sample Bias (mV)')
title('dI/dV from Aux')
hold off

% Save plot as PDF
dIdV_pdf_file = 'dIdV_map_plot.pdf';
saveas(gcf, dIdV_pdf_file);
disp(['Plot saved to: ', dIdV_pdf_file]);

% Save data to text file
dIdV_txt_file = 'dIdV_map_data.txt';
fid = fopen(dIdV_txt_file, 'w');

% Write setpoints
fprintf(fid, 'Voltage Setpoint (mV): %.3f\n', voltage_setpoint);
fprintf(fid, 'Current Setpoint (nA): %.3e\n', current_setpoint);
fprintf(fid, '--------------------------------------\n');
fprintf(fid, 'Distance(pixels)\tSampleBias(mV)\tdI/dV\n');

% Write data
for i = 1:size(II,1)
    for j = 1:size(II,2)
        fprintf(fid, '%.6f\t%.6f\t%.6f\n', j, Xdata(x1 + i - 1), log(II(i, j)));
    end
end

fclose(fid);
disp(['Data saved to: ', dIdV_txt_file]);


%% Process and Plot Edge vs Bulk Spectra



% Smoothing using a Gaussian weighting function
x = Xdata(:,1);
sigma = 17;  % Width parameter
weighting_function = exp(-(x/sigma).^2);
weighting_function = weighting_function / sum(weighting_function);
smoothed_data = conv(edge, weighting_function, 'same');

% Plotting the edge vs bulk spectra
figure()
hold on
plot(Xdata(:,1), (smooth(smoothed_data(:,1),1)) - 0.368, 'r', 'LineWidth', 2)
plot(Xdata(:,1), (smooth(bulk(:,1),1)) - 0.368, 'k', 'LineWidth', 2)

legend('edge', 'bulk')
axis square
xlabel('Voltage (mV)')
ylabel('AuX1 (arb. u.)')

% Save plot as PDF
spectra_pdf_file = 'edge_bulk_plot.pdf';
saveas(gcf, spectra_pdf_file);
disp(['Plot saved to: ', spectra_pdf_file]);

% Save data to text file
spectra_txt_file = 'edge_bulk_data.txt';
fid = fopen(spectra_txt_file, 'w');

% Write setpoints
fprintf(fid, 'Voltage Setpoint (mV): %.3f\n', voltage_setpoint);
fprintf(fid, 'Current Setpoint (nA): %.3e\n', current_setpoint);
fprintf(fid, '--------------------------------------\n');
fprintf(fid, 'Voltage(mV)\tEdge\tBulk\n');

% Write data
for i = 1:length(Xdata(:,1))
    fprintf(fid, '%.6f\t%.6f\t%.6f\n', Xdata(i,1), (smooth(smoothed_data(i),1)) - 0.368, (smooth(bulk(i),1)) - 0.368);
end

fclose(fid);
disp(['Data saved to: ', spectra_txt_file]);

disp('Processing and saving completed.');
