%% Load Data
close all
clear all

load 'data_1 nm ribbon LineSpecEndstate.mat'

% Define voltage and current setpoints
voltage_setpoint = -300;  % Example voltage setpoint in millivolts
current_setpoint = 0.2;  % Example current setpoint in nanoamperes

%% Process and Plot dI/dV Map

II = conv2(interp2(smootheddataY(1:401,1:end),1),1);
II = smooth2a(II, 1, 1);

x1 = 1;
x2 = 401;
dim = size(II);

% Create and save the dI/dV map
figure()
imagesc([0 dim(2)], [Xdata(x1) Xdata(x2)], log(II))
colorbar
colormap jet
% caxis([-1.03 -0.2])
set(gcf,'units','points','position',[25,35,1100,540])
set(gca,'FontSize',20)
xlabel('Distance (pixels)')
ylabel('Sample Bias (mV)')
title('dI/dV from Aux')
hold off

% Save plot as PDF
dIdV_pdf_file = 'dIdV_map_plot.pdf';
saveas(gcf, dIdV_pdf_file);
disp(['Plot saved to: ', dIdV_pdf_file]);

% Save data to text file
dIdV_txt_file = 'dIdV_map_data.txt';
fid = fopen(dIdV_txt_file, 'w');

% Write setpoints
fprintf(fid, 'Voltage Setpoint (mV): %.3f\n', voltage_setpoint);
fprintf(fid, 'Current Setpoint (nA): %.3e\n', current_setpoint);
fprintf(fid, '--------------------------------------\n');
fprintf(fid, 'Distance(pixels)\tSampleBias(mV)\tdI/dV\n');

% Write data
for i = 1:size(II,1)
    for j = 1:size(II,2)
        fprintf(fid, '%.6f\t%.6f\t%.6f\n', j, Xdata(x1 + i - 1), log(II(i, j)));
    end
end

fclose(fid);
disp(['Data saved to: ', dIdV_txt_file]);


