close all
clear all
load All_data_1nm_ribbon.mat

% Define colors for different curves
colors = {'r', 'b', 'g', 'k', 'm', 'c'}; 

% Prepare a figure to plot all data
figure();
hold on;

% Plot all curves with distinct colors
plot(xData1, yData1, 'Color', colors{1}, 'LineWidth', 2);
plot(xData2, yData2, 'Color', colors{2}, 'LineWidth', 2);
plot(xData2, all_yData(:,1), 'Color', colors{3}, 'LineWidth', 2);
plot(xData2, all_yData(:,2), 'Color', colors{4}, 'LineWidth', 2);
plot(xData2, all_yData(:,3), 'Color', colors{5}, 'LineWidth', 2);

% Customize the plot
xlabel('Voltage (mV)');
ylabel('Current (nA)');
title('Extracted Data from Figures');
legend({'Curve 1', 'Curve 2', 'Curve 3', 'Curve 4', 'Curve 5'});
grid on;
box on;
axis square;

% Save the combined plot as PDF
outputPdfFile = 'combined_extracted_data_plot.pdf';
saveas(gcf, outputPdfFile);
disp(['Combined plot saved to: ', outputPdfFile]);

%% Save data to text file
outputTxtFile = 'curves_data.txt';
fid = fopen(outputTxtFile, 'w');

% Voltage and current setpoints
voltage_setpoint = -300;  % Example setpoint in millivolts
current_setpoint = 0.2;   % Example setpoint in nanoamperes

fprintf(fid, 'Voltage Setpoint (mV): %.3f\n', voltage_setpoint);
fprintf(fid, 'Current Setpoint (nA): %.3e\n', current_setpoint);
fprintf(fid, '--------------------------------------\n');

% Write header
fprintf(fid, 'Voltage(mV)\tCurve1(nA)\tCurve2(nA)\tCurve3(nA)\tCurve4(nA)\tCurve5(nA)\n');

% Write combined data
for i = 1:length(xData2)
    fprintf(fid, '%.6f', xData2(i));
    fprintf(fid, '\t%.6f\t%.6f\t%.6f\t%.6f\t%.6f\n', yData2(i), all_yData(i,1), all_yData(i,2), all_yData(i,3), yData1(i));
end

fclose(fid);
disp(['Combined data saved to: ', outputTxtFile]);

%% Save data to MAT file
outputMatFile = 'curves_data.mat';
save(outputMatFile, 'xData1', 'yData1', 'xData2', 'yData2', 'all_yData', 'voltage_setpoint', 'current_setpoint');
disp(['Combined data saved to: ', outputMatFile]);

hold off;
disp('All data has been plotted and saved.');
