close all
clear all
load MATLABDATA_forpaper.mat

% Define pure red and pure blue in RGB
RGBstart = [1 0 0];  % pure red
RGBend   = [0 0 1];  % pure blue

nCurves = 7;  % number of data sets
rgbMap = zeros(nCurves,3);

% Create a linear color gradient from red to blue in RGB space
for i = 1:nCurves
    t = (i-1)/(nCurves-1);   % parameter from 0 to 1
    rgbMap(i,:) = (1 - t)*RGBstart + t*RGBend;
end

figure(); hold on

% Plot commands, each with a distinct color:
plot(DOS_2p2(50:end,2), smooth(DOS_0p2_cal,20)+0.8,  'Color', rgbMap(1,:));
plot(DOS_2p2(50:end,2), smooth(DOS_2p2_cal,10)+1.8,  'Color', rgbMap(7,:));
plot(DOS_2p2(50:end,2), smooth(DOS_1p7down_cal,10)+2.2, 'Color', rgbMap(6,:));
plot(DOS_2p2(50:end,2), smooth(DOS_1p5down_cal,10)+2.6, 'Color', rgbMap(5,:));
plot(DOS_2p2(50:end,2), smooth(DOS_1p2down_cal,10)+3,   'Color', rgbMap(4,:));
plot(DOS_2p2(50:end,2), smooth(DOS_0p7down_cal,10)+3.4, 'Color', rgbMap(3,:));
plot(DOS_2p2(50:end,2), smooth(DOS_0p4down_cal,10)+3.8, 'Color', rgbMap(2,:));
plot(DOS_2p2(50:end,2), smooth(DOS_0p2down_cal,10)+4.2, 'Color', rgbMap(1,:));

xlim([-0.1 0.3])
xlabel('sample bias (V)')
ylabel('norm dI/dV (arb.u.)')

% Place legend outside the figure (to the right)
legend('0.2 nA','2.2 nA','1.7 nA','1.5 nA','1.2 nA','0.7 nA','0.4 nA','0.2 nA', ...
       'Location','eastoutside')

% Remove the y-axis ticks
set(gca, 'YTick', [])

% Make axis rectangular with a ~2.5:1 ratio (Y:X)
pbaspect([1 2.5 1])
box on

% Save figure as PDF and JPG
saveas(gcf, 'ElectricField_SI.pdf');
saveas(gcf, 'ElectricField_SI.jpg');

% Save the data used for plots in text files
writematrix([DOS_2p2(50:end,2), smooth(DOS_0p2_cal,20)+0.8],  'DOS_0p2_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_2p2_cal,10)+1.8],  'DOS_2p2_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_1p7down_cal,10)+2.2], 'DOS_1p7down_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_1p5down_cal,10)+2.6], 'DOS_1p5down_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_1p2down_cal,10)+3],   'DOS_1p2down_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_0p7down_cal,10)+3.4], 'DOS_0p7down_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_0p4down_cal,10)+3.8], 'DOS_0p4down_cal.txt');
writematrix([DOS_2p2(50:end,2), smooth(DOS_0p2down_cal,10)+4.2], 'DOS_0p2down_cal.txt');
